@@ -1,6 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
-
 from .. import Provider as AddressProvider
 
 
@@ -300,10 +297,8 @@ class Provider(AddressProvider):
         'ჯვარი',
     )
 
-    @classmethod
-    def street_title(cls):
-        return cls.random_element(cls.street_titles)
+    def street_title(self):
+        return self.random_element(self.street_titles)
 
-    @classmethod
-    def city_name(cls):
-        return cls.random_element(cls.city_names)
+    def city_name(self):
+        return self.random_element(self.city_names)
