@@ -1,5 +1,3 @@
-# coding=utf-8
-from __future__ import unicode_literals
 from .. import Provider as PersonProvider
 
 
@@ -46,9 +44,9 @@ class Provider(PersonProvider):
     first_names_male = (
         'تاج', 'تامر', 'تحسين', 'تقي', 'تمّام', 'تميم', 'توفيق', 'ترف',
         'تاج الدّين', 'تقيّ الدّين', 'ثائر', 'ثابت', 'ثامر', 'ثروت',
-        'ثقيف', 'ثاقب', 'جابر', 'جاد', 'جاسم', 'جرير', 'جسور', 
+        'ثقيف', 'ثاقب', 'جابر', 'جاد', 'جاسم', 'جرير', 'جسور',
         'جعفر', 'جلاء', 'جلال', 'جليل', 'جمال', 'جميل', 'جدير',
-        'جرّاح', 'جلال الدّين', 'جمال الدّين','جهاد', 'حاتم', 'حارث',
+        'جرّاح', 'جلال الدّين', 'جمال الدّين', 'جهاد', 'حاتم', 'حارث',
         'حازم', 'حافظ', 'حامد', 'حبّاب', 'حسام', 'حسن', 'حسيب',
         'حسين', 'حسني', 'حسنين', 'حقّي', 'حكيم', 'حليم', 'حمّاد',
         'حمدان', 'حمدي', 'حمزة', 'حمود', 'حميد', 'حنبل', 'حنفي',
@@ -72,7 +70,7 @@ class Provider(PersonProvider):
         'شادي', 'شافع', 'شاكر', 'شامخ', 'شامل', 'شبلي', 'شبيب',
         'شدّاد', 'شريف', 'شعبان', 'شعيب', 'شفيع', 'شعلان', 'شكري',
         'شكيب', 'شهب', 'شهاب', 'شهم', 'شهير', 'شوقي', 'شجاع', 'شاطر',
-        'شيّق', 'صائب', 'صابر', 'صاحب', 'صادح' 'صادق', 'صارم',
+        'شيّق', 'صائب', 'صابر', 'صاحب', 'صادح', 'صادق', 'صارم',
         'صافي', 'صالح', 'صامد', 'صباح', 'صبحي', 'صبري', 'صبور',
         'صبيح', 'صخر', 'صدقي', 'صدّام', 'صدّاح', 'صعب', 'صقر',
         'صلاح', 'صنديد', 'صهيب', 'صدر الدّين', 'صلاح الدّين', 'ضاحك',
@@ -80,11 +78,11 @@ class Provider(PersonProvider):
         'طائع', 'طائف', 'طائل', 'طارق', 'طالب', 'طامح', 'طاهر',
         'طبّاع', 'طريف', 'طلال', 'طلعت', 'طموح', 'طه', 'طيّب',
         'طيّع', 'ظافر', 'ظبي', 'ظريف', 'ظهير', 'ظاعن', 'ظاهر',
-        'عائد', 'عابد', 'عادل', 'عارف', 'عاصم', 'عاطف' 'عاقل',
+        'عائد', 'عابد', 'عادل', 'عارف', 'عاصم', 'عاطف', 'عاقل',
         'عاكف', 'عالم', 'عامر', 'عبّاس', 'عبّود', 'عتريس', 'عتيد',
         'عربي', 'عثمان', 'عدلي', 'عدنان', 'عدوي', 'عرفات', 'عرفه',
         'عرفان', 'عزاز', 'عزّت', 'عزمي', 'عصام', 'عصمت', 'عطاء',
-        'عفيف', 'عقيل' 'علاء', 'علّام', 'علوان', 'علي', 'عماد',
+        'عفيف', 'عقيل', 'علاء', 'علّام', 'علوان', 'علي', 'عماد',
         'عمّار', 'عمر', 'عمران', 'عمرو', 'عمير', 'عاتب', 'عتيق',
         'عذب', 'عزيز', 'عبد الحقّ', 'عبدالله', 'عبدالرّحمن',
         'عزّالدّين', 'علاءالدّين', 'علم الدّين', 'عبد الإله', 'مُتعب',
@@ -93,7 +91,7 @@ class Provider(PersonProvider):
         'عبد الحيّ', 'عبد المحيي', 'عبد الخالق', 'عبد الرّزاق', 'هزار',
         'عبد الرّشيد', 'عبد الرّحمن', 'عبد الرّحيم', 'عبد الرّؤوف',
         'عبد السّميع', 'عبد الشّكور', 'عبد الصّمد', 'عبد العليم',
-        'عبد الغفّار', 'عبد الغفور', 'عبد القادر',  'مهنّد', 'نزيه',
+        'عبد الغفّار', 'عبد الغفور', 'عبد القادر', 'مهنّد', 'نزيه',
         'عبد القدّوس', 'عبد القهّار', 'عبد الكريم', 'عبد اللطيف',
         'عبد المجيد', 'عبد المولى', 'عبد العزيز', 'عبد السّلام',
         'عبد الملك', 'عبد الواحد', 'عبد الغني', 'غازي', 'غالب',
@@ -195,4 +193,4 @@ class Provider(PersonProvider):
     prefixes_female = (
         'السيدة', 'الآنسة', 'الدكتورة', 'الأستاذة', 'المهندسة',
     )
-    prefixes_male = ('السيد', 'المهندس', 'الدكتور', 'الأستاذ',)
+    prefixes_male = ('السيد', 'المهندس', 'الدكتور', 'الأستاذ')
