@@ -272,6 +272,35 @@ class Provider(PersonProvider):
 
     middle_names = middle_names_male + middle_names_female
 
+    language_names = (
+        'Афарский', 'Абхазский', 'Авестийский', 'Африкаанс', 'Акан',
+        'Амхарский', 'Арагонский', 'Арабский', 'Ассамский', 'Аварский',
+        'Аймарский', 'Азербайджанский', 'Башкирский', 'Белорусский',
+        'Болгарский', 'Бислама', 'Бенгальский', 'Тибетский', 'Бретонский',
+        'Боснийский', 'Каталанский', 'Чеченский', 'Чаморро', 'Корсиканский',
+        'Кри', 'Чешский', 'Чувашский', 'Валлийский', 'Датский', 'Немецкий',
+        'Греческий', 'Английский', 'Эсперанто', 'Испанский', 'Эстонский',
+        'Персидский', 'Финский', 'Фиджийский', 'Фарси', 'Французский',
+        'Ирландский', 'Гэльский', 'Галийский', 'Иврит', 'Хинди',
+        'Хорватский', 'Гавайский', 'Болгарский', 'Армянский',
+        'Индонезийский', 'Исландский', 'Итальянский', 'Японский',
+        'Яванский', 'Грузинский', 'Казахский', 'Корейский', 'Кашмири',
+        'Курдский', 'Коми', 'Киргизский', 'Латинский', 'Люксембургский',
+        'Лимбургский', 'Лингала', 'Лаосский', 'Литовский', 'Латвийский',
+        'Малагасийский', 'Маршалльский', 'Маори', 'Македонский', 'Малаялам',
+        'Монгольский', 'Маратхи', 'Малайский', 'Мальтийский', 'Непальский',
+        'Нидерландский', 'Норвежский', 'Навахо', 'Оромо', 'Ория',
+        'Осетинский', 'Пали', 'Польский', 'Пушту', 'Португальский',
+        'Романшский', 'Румынский', 'Русский', 'Киньяруанда',
+        'Санскрит', 'Сардинский', 'Санго', 'Сингальский',
+        'Словацкий', 'Словенский', 'Самоанский', 'Сомалийский', 'Албанский',
+        'Сербский', 'Сунданский', 'Шведский', 'Суахили', 'Тамильский',
+        'Телугу', 'Таджикский', 'Тайский', 'Тигринья', 'Туркменский',
+        'Тагальский', 'Тсвана', 'Тонга', 'Турецкий', 'Тсонга', 'Татарский',
+        'Таитянский', 'Уйгурский', 'Украинский', 'Урду', 'Узбекский', 'Венда',
+        'Вьетнамский', 'Идиш', 'Йоруба', 'Китайский', 'Зулу',
+    )
+
     prefixes_male = ('г-н', 'тов.')
 
     prefixes_female = ('г-жа', 'тов.')
